summaryrefslogtreecommitdiffstats
path: root/Lib
diff options
context:
space:
mode:
authorRaymond Hettinger <python@rcn.com>2005-01-11 15:33:03 (GMT)
committerRaymond Hettinger <python@rcn.com>2005-01-11 15:33:03 (GMT)
commitfaa10ebdd0c250a59b9073c6e0829c42fedfac43 (patch)
tree32aba93f78f876954cd62c43bf9c55a197e9f866 /Lib
parente4d05c4f93d0cf4359a5df5862110d94c8216de4 (diff)
downloadcpython-faa10ebdd0c250a59b9073c6e0829c42fedfac43.zip
cpython-faa10ebdd0c250a59b9073c6e0829c42fedfac43.tar.gz
cpython-faa10ebdd0c250a59b9073c6e0829c42fedfac43.tar.bz2
SF bug #1099516: tempfile files not types.FileType
Clarified that the returned object is file-like rather than an actual file.
Diffstat (limited to 'Lib')
-rw-r--r--Lib/tempfile.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/Lib/tempfile.py b/Lib/tempfile.py
index ae2ed9e..dd7e864 100644
--- a/Lib/tempfile.py
+++ b/Lib/tempfile.py
@@ -414,9 +414,9 @@ def NamedTemporaryFile(mode='w+b', bufsize=-1, suffix="",
'bufsize' -- the buffer size argument to os.fdopen (default -1).
The file is created as mkstemp() would do it.
- Returns a file object; the name of the file is accessible as
- file.name. The file will be automatically deleted when it is
- closed.
+ Returns an object with a file-like interface; the name of the file
+ is accessible as file.name. The file will be automatically deleted
+ when it is closed.
"""
if dir is None:
@@ -451,8 +451,8 @@ else:
'bufsize' -- the buffer size argument to os.fdopen (default -1).
The file is created as mkstemp() would do it.
Returns a file object. The file has no name, and will cease to
exist when it is closed.
"""
if dir is None:
@@ -451,8 +451,8 @@ else:
'bufsize' -- the buffer size argument to os.fdopen (default -1).
The file is created as mkstemp() would do it.
- Returns a file object. The file has no name, and will cease to
- exist when it is closed.
+ Returns an object with a file-like interface. The file has no
+ name, and will cease to exist when it is closed.
"""
if dir is None: